//
//  FlybitsContextLocationSDK.h
//  FlybitsContextLocationSDK
//
//  Created by Caio on 2019-04-11.
//  Copyright © 2019 Flybits. All rights reserved.
//

#import <Foundation/Foundation.h>

//! Project version number for FlybitsContextLocationSDK.
FOUNDATION_EXPORT double FlybitsContextLocationSDKVersionNumber;

//! Project version string for FlybitsContextLocationSDK.
FOUNDATION_EXPORT const unsigned char FlybitsContextLocationSDKVersionString[];

// In this header, you should import all the public headers of your framework using statements like #import <FlybitsContextLocationSDK/PublicHeader.h>


